@@ -23,6 +23,7 @@
 #include "dotdefaults.h"
 #include "dot2qtconsts.h"
 #include "FontsCache.h"
+#include "kgraphviewerlib_debug.h"
 
 #include <stdlib.h>
 #include <math.h>
@@ -33,9 +34,9 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QMenu>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <KAction>
+#include <QDebug>
+#include <QAction>
+#include <klocalizedstring.h>
 
 // comment out to get extended debug output during rendering
 // #define RENDER_DEBUG 1
@@ -56,19 +57,19 @@ CanvasElement::CanvasElement(
                             )
   : QObject(), QAbstractGraphicsShapeItem(parent),
     m_scaleX(0), m_scaleY(0),
-    m_xMargin(0), m_yMargin(0), m_gh(0), m_wdhcf(0), m_hdvcf(0),
+    m_xMargin(0), m_yMargin(0), m_gh(0),
     m_element(gelement), m_view(v),
-    m_font(0),
+    m_font(nullptr),
     m_pen(Dot2QtConsts::componentData().qtColor(gelement->fontColor())),
     m_popup(new QMenu()),
     m_hovered(false),
     m_lastRenderOpRev(0)
 {
-//   kDebug();
+//   qCDebug(KGRAPHVIEWERLIB_LOG);
   m_font = FontsCache::changeable().fromName(gelement->fontName());
 
-/*  kDebug() << "Creating CanvasElement for "<<gelement->id();
-  kDebug() << "    data: " << wdhcf << "," << hdvcf << "," << gh << "," 
+/*  qCDebug(KGRAPHVIEWERLIB_LOG) << "Creating CanvasElement for "<<gelement->id();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "    data: " << wdhcf << "," << hdvcf << "," << gh << "," 
     << scaleX << "," << scaleY << "," << xMargin << "," << yMargin << endl;*/
   
   if (element()->style() == "bold")
@@ -98,18 +99,23 @@ CanvasElement::CanvasElement(
   }
   
   // the message should be given (or possible to be given) by the part user
-  KAction* removeElementAction = new KAction(i18n("Remove selected element(s)"), this);
+  QAction* removeElementAction = new QAction(i18n("Remove selected element(s)"), this);
   m_popup->addAction(removeElementAction);
-  connect(removeElementAction,SIGNAL(triggered(bool)),this,SLOT(slotRemoveElement()));
+  connect(removeElementAction, &QAction::triggered,
+          this, &CanvasElement::slotRemoveElement);
 
-  connect(this, SIGNAL(selected(CanvasElement*,Qt::KeyboardModifiers)), v, SLOT(slotElementSelected(CanvasElement*,Qt::KeyboardModifiers)));
+  connect(this, &CanvasElement::selected,
+          v, &DotGraphView::slotElementSelected);
 
-  connect(this, SIGNAL(elementContextMenuEvent(QString,QPoint)), v, SLOT(slotContextMenuEvent(QString,QPoint)));
+  connect(this, &CanvasElement::elementContextMenuEvent,
+          v, &DotGraphView::slotContextMenuEvent);
 
   setAcceptHoverEvents ( true );
 
-  connect(this, SIGNAL(hoverEnter(CanvasElement*)), v, SLOT(slotElementHoverEnter(CanvasElement*)));
-  connect(this, SIGNAL(hoverLeave(CanvasElement*)), v, SLOT(slotElementHoverLeave(CanvasElement*)));
+  connect(this, &CanvasElement::hoverEnter,
+          v, static_cast<void(DotGraphView::*)(CanvasElement*)>(&DotGraphView::slotElementHoverEnter));
+  connect(this, &CanvasElement::hoverLeave,
+          v, static_cast<void(DotGraphView::*)(CanvasElement*)>(&DotGraphView::slotElementHoverLeave));
   
 }
 
@@ -120,7 +126,7 @@ CanvasElement::~CanvasElement()
 
 void CanvasElement::modelChanged()
 {
-  kDebug() ;//<< id();
+  qCDebug(KGRAPHVIEWERLIB_LOG) ;//<< id();
   m_pen = QPen(Dot2QtConsts::componentData().qtColor(m_element->fontColor()));
   m_font = FontsCache::changeable().fromName(m_element->fontName());
   prepareGeometryChange();
@@ -128,17 +134,16 @@ void CanvasElement::modelChanged()
 }
 
 void CanvasElement::initialize(qreal scaleX, qreal scaleY,
-                            qreal xMargin, qreal yMargin, qreal gh,
-                            qreal wdhcf, qreal hdvcf)
+                            qreal xMargin, qreal yMargin, qreal gh)
 {
-//   kDebug();
+  Q_UNUSED(gh);
+//   qCDebug(KGRAPHVIEWERLIB_LOG);
   setFlag(QGraphicsItem::ItemIsMovable, true);
   setFlag(QGraphicsItem::ItemIsSelectable, true);
 
   m_scaleX = scaleX; m_scaleY = scaleY;
   m_xMargin = xMargin; m_yMargin = yMargin;
 //   m_gh = gh;
-  m_wdhcf = wdhcf; m_hdvcf = hdvcf;
 
   setZValue(m_element->z());
 
@@ -152,14 +157,14 @@ QRectF CanvasElement::boundingRect () const
 
 void CanvasElement::computeBoundingRect()
 {
-//   kDebug() << element();
-  kDebug() << element()->id() << zValue();
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << element();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << element()->id() << zValue();
   
   qreal adjust = 0.5;
   QRectF rect;
   if (element()->renderOperations().isEmpty())
   {
-    kDebug() << "no render operation";
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "no render operation";
     rect = QRectF(0,0,(m_view->defaultNewElementPixmap().size().width())*m_scaleX,(m_view->defaultNewElementPixmap().size().height())*m_scaleY);
     m_boundingRect = rect;
   }
@@ -178,19 +183,18 @@ void CanvasElement::computeBoundingRect()
         dd << i << " ";
       }
       dd << (*it).str;
-      kDebug() << msg;
+      qCDebug(KGRAPHVIEWERLIB_LOG) << msg;
 #endif
 
       if ((*it).renderop == "e" || (*it).renderop == "E")
       {
-//         kDebug() << "integers[0]=" << (*it).integers[0] << "; m_wdhcf=" << m_wdhcf
-//             << "(*it).integers[0]/*%m_wdhcf*/=" << (*it).integers[0]/*%m_wdhcf*/;
+//         qCDebug(KGRAPHVIEWERLIB_LOG) << "integers[0]=" << (*it).integers[0] << ";
         qreal w = m_scaleX * (*it).integers[2] * 2;
         qreal h = m_scaleY * (*it).integers[3] * 2;
-        qreal x = m_xMargin + (((*it).integers[0]/*%m_wdhcf*/)*m_scaleX) - w/2;
-        qreal y = ((m_gh - (*it).integers[1]/*%m_hdvcf*/)*m_scaleY) + m_yMargin - h/2;
+        qreal x = m_xMargin + (((*it).integers[0])*m_scaleX) - w/2;
+        qreal y = ((m_gh - (*it).integers[1])*m_scaleY) + m_yMargin - h/2;
         m_boundingRect = QRectF(x - adjust,y - adjust, w + adjust, h + adjust);
-//         kDebug() << "'" << element()->id() << "' set rect for ellipse to " << rect;
+//         qCDebug(KGRAPHVIEWERLIB_LOG) << "'" << element()->id() << "' set rect for ellipse to " << rect;
       }
       else if  ((*it).renderop == "p" || (*it).renderop == "P")
       {
@@ -198,8 +202,8 @@ void CanvasElement::computeBoundingRect()
         for (int i = 0; i < (*it).integers[0]; i++)
         {
           qreal x,y;
-          x = ((*it).integers[2*i+1] == m_wdhcf)?(*it).integers[2*i+1]:(*it).integers[2*i+1]/*%m_wdhcf*/;
-          y = ((*it).integers[2*i+2] == m_hdvcf)?(*it).integers[2*i+2]:(*it).integers[2*i+2]/*%m_hdvcf*/;
+          x = (*it).integers[2*i+1];
+          y = (*it).integers[2*i+2];
           {
 
           }
@@ -210,7 +214,7 @@ void CanvasElement::computeBoundingRect()
           polygon[i] = p;
         }
         m_boundingRect = polygon.boundingRect();
-//         kDebug() << "'" << element()->id() << "' set rect for polygon to " << rect;
+//         qCDebug(KGRAPHVIEWERLIB_LOG) << "'" << element()->id() << "' set rect for polygon to " << rect;
       }
     }
   }
@@ -246,12 +250,12 @@ QWidget *widget)
     }
     dd << op.str << endl;
   }
-  kDebug() << msg;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << msg;
 #endif
 
   if (element()->renderOperations().isEmpty() && m_view->isReadWrite())
   {
-    kError() << element()->id() << ": no render operation. This should not happen.";
+    qCWarning(KGRAPHVIEWERLIB_LOG) << element()->id() << ": no render operation. This should not happen.";
     return;
   }
 
@@ -278,7 +282,7 @@ QWidget *widget)
       bool ok;
       c.setAlpha(255-dro.str.mid(8).toInt(&ok,16));
       lineColor = c;
-//       kDebug() << "c" << dro.str.mid(0,7) << lineColor;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "c" << dro.str.mid(0,7) << lineColor;
     }
     else if (dro.renderop == "C")
     {
@@ -290,15 +294,15 @@ QWidget *widget)
         c = c.lighter();
       }
       backColor = c;
-//       kDebug() << "C" << dro.str.mid(0,7) << backColor;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "C" << dro.str.mid(0,7) << backColor;
     }
     else if (dro.renderop == "e" || dro.renderop == "E")
     {
       QPen pen = oldPen;
       qreal w = m_scaleX * dro.integers[2] * 2;
       qreal h = m_scaleY * dro.integers[3] * 2;
-      qreal x = m_xMargin + ((dro.integers[0]/*%m_wdhcf*/)*m_scaleX) - w/2;
-      qreal y = ((m_gh - dro.integers[1]/*%m_hdvcf*/)*m_scaleY) + m_yMargin - h/2;
+      qreal x = m_xMargin + (dro.integers[0]*m_scaleX) - w/2;
+      qreal y = ((m_gh - dro.integers[1])*m_scaleY) + m_yMargin - h/2;
       QRectF rect(x,y,w,h);
       pen.setColor(lineColor);
       if (element()->attributes().contains("penwidth"))
@@ -311,7 +315,7 @@ QWidget *widget)
       p->setBrush(backColor);
       p->setPen(pen);
 
-//       kDebug() << element()->id() << "drawEllipse" << lineColor << backColor << rect;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << element()->id() << "drawEllipse" << lineColor << backColor << rect;
 //       rect = QRectF(0,0,100,100);
       p->drawEllipse(rect);
     }
@@ -322,14 +326,14 @@ QWidget *widget)
       for (int i = 0; i < dro.integers[0]; i++)
       {
         qreal x,y;
-        x = (dro.integers[2*i+1] == m_wdhcf)?dro.integers[2*i+1]:dro.integers[2*i+1]/*%m_wdhcf*/;
-        y = (dro.integers[2*i+2] == m_hdvcf)?dro.integers[2*i+2]:dro.integers[2*i+2]/*%m_hdvcf*/;
+        x = dro.integers[2*i+1];
+        y = dro.integers[2*i+2];
         QPointF p(
                   (x*m_scaleX) + m_xMargin,
                   ((m_gh-y)*m_scaleY) + m_yMargin
                 );
-/*        kDebug() << "    point: (" << dro.integers[2*i+1] << ","
-                  << dro.integers[2*i+2] << ") " << m_wdhcf << "/" << m_hdvcf;*/
+/*        qCDebug(KGRAPHVIEWERLIB_LOG) << "    point: (" << dro.integers[2*i+1] << ","
+                  << dro.integers[2*i+2] << ") " */
         points[i] = p;
       }
 
@@ -367,7 +371,7 @@ QWidget *widget)
       {
         p->setBrush(canvas()->backgroundColor());
       }*/
-//       kDebug() << element()->id() << "drawPolygon" << points;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << element()->id() << "drawPolygon" << points;
       p->drawPolygon(points);
       if (!element()->shapeFile().isEmpty())
       {
@@ -394,7 +398,7 @@ QWidget *widget)
       bool ok;
       c.setAlpha(255-dro.str.mid(8).toInt(&ok,16));
       lineColor = c;
-//       kDebug() << "c" << dro.str.mid(0,7) << lineColor;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "c" << dro.str.mid(0,7) << lineColor;
     }
     else if (dro.renderop == "C")
     {
@@ -406,17 +410,17 @@ QWidget *widget)
         c = c.lighter();
       }
       backColor = c;
-//       kDebug() << "C" << dro.str.mid(0,7) << backColor;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "C" << dro.str.mid(0,7) << backColor;
     }
     else if ( dro.renderop == "L" )
     {
-//       kDebug() << "Label";
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "Label";
       QPolygonF points(dro.integers[0]);
       for (int i = 0; i < dro.integers[0]; i++)
       {
         qreal x,y;
-        x = (dro.integers[2*i+1] == m_wdhcf)?dro.integers[2*i+1]:dro.integers[2*i+1]/*%m_wdhcf*/;
-        y = (dro.integers[2*i+2] == m_hdvcf)?dro.integers[2*i+2]:dro.integers[2*i+2]/*%m_hdvcf*/;
+        x = dro.integers[2*i+1];
+        y = dro.integers[2*i+2];
         QPointF p(
                   (x*m_scaleX) +m_xMargin,
                   ((m_gh-y)*m_scaleY) + m_yMargin
@@ -434,13 +438,13 @@ QWidget *widget)
         pen.setStyle(Dot2QtConsts::componentData().qtPenStyle(element()->style()));
       }
       p->setPen(pen);
-//       kDebug() << element()->id() << "drawPolyline" << points;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << element()->id() << "drawPolyline" << points;
       p->drawPolyline(points);
     }
   }
   p->setPen(oldPen);
 
-//   kDebug() << "Drawing" << element()->id() << "labels";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Drawing" << element()->id() << "labels";
   QString color = lineColor.name();
   it.toFront();
   uint num_T = 0;
@@ -450,13 +454,13 @@ QWidget *widget)
     if (dro.renderop == "c" || dro.renderop == "C")
     {
       color = dro.str.mid(0,7);
-//       kDebug() << dro.renderop << color;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << dro.renderop << color;
     }
     else if (dro.renderop == "F")
     {
       element()->setFontName(dro.str);
       element()->setFontSize(dro.integers[0]);
-//       kDebug() << "F" << element()->fontName() << element()->fontColor() << element()->fontSize();
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "F" << element()->fontName() << element()->fontColor() << element()->fontSize();
     }
     else if ( dro.renderop == "T" )
     {
@@ -464,7 +468,7 @@ QWidget *widget)
       // we suppose here that the color has been set just before
       element()->setFontColor(color);
       // draw a label
-//       kDebug() << "Drawing a label " << dro.integers[0]
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "Drawing a label " << dro.integers[0]
 //       << " " << dro.integers[1] << " " << dro.integers[2]
 //       << " " << dro.integers[3] << " " << dro.str
 //         << " (" << element()->fontName() << ", " << element()->fontSize()
@@ -472,7 +476,7 @@ QWidget *widget)
 
       int fontWidth = 0;
       bool cacheValid = false;
-//       kDebug() << element()->id() << " initial fontSize " << fontSize;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << element()->id() << " initial fontSize " << fontSize;
       if (m_lastRenderOpRev == element()->renderOperationsRevision()) {
         FontSizeCache::iterator cacheIt = m_fontSizeCache.find(num_T);
         if (cacheIt != m_fontSizeCache.end()) {
@@ -513,14 +517,14 @@ QWidget *widget)
                       + m_xMargin;
       qreal y = ((m_gh - (dro.integers[1]))*m_scaleY)+ m_yMargin;
       QPointF point(x,y);
-//       kDebug() << element()->id() << "drawText" << point << " " << fontSize;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << element()->id() << "drawText" << point << " " << fontSize;
       p->drawText(point, dro.str);
     }
   }
 
   if (element()->isSelected())
   {
-//     kDebug() << "element is selected: draw selection marks";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "element is selected: draw selection marks";
     p->setBrush(Qt::black);
     p->setPen(Qt::black);
     p->drawRect(QRectF(m_boundingRect.topLeft(),QSizeF(6,6)));
@@ -538,7 +542,7 @@ QWidget *widget)
 
 void CanvasElement::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
-  kDebug() << m_element->id() << boundingRect();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << m_element->id() << boundingRect();
   if (m_view->isReadOnly())
   {
     return;
@@ -572,7 +576,7 @@ void CanvasElement::mousePressEvent(QGraphicsSceneMouseEvent* event)
       update();
     }
     
-//     kDebug() << "opens the contextual menu";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "opens the contextual menu";
 //     m_popup->exec(event->screenPos());
     emit(elementContextMenuEvent(m_element->id(), event->screenPos() ));
   }
@@ -581,25 +585,24 @@ void CanvasElement::mousePressEvent(QGraphicsSceneMouseEvent* event)
 void CanvasElement::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
   Q_UNUSED(event)
-//   kDebug() ;
+//   qCDebug(KGRAPHVIEWERLIB_LOG) ;
 }
 
 void CanvasElement::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
 {
   Q_UNUSED(event)
-//   kDebug() ;
+//   qCDebug(KGRAPHVIEWERLIB_LOG) ;
 }
 
 void CanvasElement::slotRemoveElement()
 {
-  kDebug();
   m_view->removeSelectedElements();
 }
 
 void CanvasElement::hoverEnterEvent( QGraphicsSceneHoverEvent * event )
 {
   Q_UNUSED(event)
-//   kDebug();
+//   qCDebug(KGRAPHVIEWERLIB_LOG);
   m_hovered = true;
   update();
   emit hoverEnter(this);
@@ -608,12 +611,10 @@ void CanvasElement::hoverEnterEvent( QGraphicsSceneHoverEvent * event )
 void CanvasElement::hoverLeaveEvent( QGraphicsSceneHoverEvent * event )
 {
   Q_UNUSED(event)
-//   kDebug();
+//   qCDebug(KGRAPHVIEWERLIB_LOG);
   m_hovered = false;
   update();
   emit hoverLeave(this);
 }
 
 }
-
-#include "canvaselement.moc"
