@@ -35,14 +35,15 @@ class DotGraphView;
 
 class CanvasSubgraph: public CanvasElement
 {
+  Q_OBJECT
 public:
   CanvasSubgraph(
       DotGraphView* v, 
       GraphSubgraph* s,
       QGraphicsScene* c,
-      QGraphicsItem* parent = 0);
-  virtual ~CanvasSubgraph() {}
-  
+      QGraphicsItem* parent = nullptr);
+  ~CanvasSubgraph() override {}
+
 protected:
 };
 
