@@ -22,10 +22,11 @@
 #include "graphnode.h"
 #include "graphedge.h"
 #include "DotGraphParsingHelper.h"
+#include "kgraphviewerlib_debug.h"
 
 #include <iostream>
 
-#include <kdebug.h>
+#include <QDebug>
     
 #include <QFile>
 
@@ -46,7 +47,7 @@ using namespace KGraphViewer;
 #define KGV_MAX_ITEMS_TO_LOAD std::numeric_limits<size_t>::max()
 #define BOOST_SPIRIT_DEBUG 1
 
-DotGraphParsingHelper* phelper = 0;
+DotGraphParsingHelper* phelper = nullptr;
 
 std::string therenderop;
 std::string thestr;
@@ -117,7 +118,8 @@ void incrz(char const /*first*/)
 
 void anychar(char const c)
 {
-//   kDebug() << c;
+    Q_UNUSED(c);
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << c;
 }
 
 void decrz(char const /*first*/)
@@ -125,14 +127,14 @@ void decrz(char const /*first*/)
   if (phelper)
   {
     phelper->z--;
-    phelper->gs = 0;
+    phelper->gs = nullptr;
   }
 }
 
 void dump(char const* first, char const* last)
 {
   std::string str(first, last);
-  kError() << ">>>> " << QString::fromStdString(str) << " <<<<" << endl;
+  qCWarning(KGRAPHVIEWERLIB_LOG) << ">>>> " << QString::fromStdString(str) << " <<<<" << endl;
 }
 
 void strict(char const* /*first*/, char const* /*last*/)
@@ -143,24 +145,24 @@ void strict(char const* /*first*/, char const* /*last*/)
 void gotid(char const* first, char const* last)
 {
   std::string id(first,last);
-//   kDebug() << "Got ID  = '"<<QString::fromStdString(phelper->attrid)<<"'";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Got ID  = '"<<QString::fromStdString(phelper->attrid)<<"'";
 }
 
 void undigraph(char const* /*first*/, char const* /*last*/)
 {
-//   kDebug() << "Setting graph as undirected";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Setting graph as undirected";
   if (phelper) phelper->graph->directed(false);
 }
 
 void digraph(char const* /*first*/, char const* /*last*/)
 {
-//   kDebug() << "Setting graph as directed";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Setting graph as directed";
   if (phelper) phelper->graph->directed(true);
 }
 
 void graphid(char const* first, char const* last)
 {
-//   kDebug() << QString::fromStdString(std::string(first,last));
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << QString::fromStdString(std::string(first,last));
   if (phelper) phelper->graph->setId(QString::fromStdString(std::string(first,last)));
 }
 
@@ -173,20 +175,20 @@ void attrid(char const* first, char const* last)
     if (id.size()>0 && id[id.size()-1] == '"') id = id.substr(0,id.size()-1);
     phelper->attrid = id;
     phelper->valid = "";
-//     kDebug() << "Got attr ID  = '"<<QString::fromStdString(phelper->attrid)<<"'";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "Got attr ID  = '"<<QString::fromStdString(phelper->attrid)<<"'";
   }
 }
 
 void subgraphid(char const* first, char const* last)
 {
   std::string id(first,last);
-//   kDebug() << QString::fromStdString(id);
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << QString::fromStdString(id);
   if (phelper) 
   {
     if (id.size()>0 && id[0] == '"') id = id.substr(1);
     if (id.size()>0 && id[id.size()-1] == '"') id = id.substr(0,id.size()-1);
     phelper->subgraphid = id;
-//     kDebug() << "Got subgraph id = '"<<QString::fromStdString(phelper->subgraphid)<<"'";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "Got subgraph id = '"<<QString::fromStdString(phelper->subgraphid)<<"'";
   }
 }
 
@@ -198,7 +200,7 @@ void valid(char const* first, char const* last)
     if (id.size()>0 && id[0] == '"') id = id.substr(1);
     if (id.size()>0 && id[id.size()-1] == '"') id = id.substr(0,id.size()-1);
     phelper->valid = id;
-//     kDebug() << "Got attr val = '"<<QString::fromStdString(id)<<"'";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "Got attr val = '"<<QString::fromStdString(id)<<"'";
   }
 }
 
@@ -212,12 +214,12 @@ void addattr(char const* /*first*/, char const* /*last*/)
 
 void pushAttrListC(char const /*c*/)
 {
-  pushAttrList(0,0);
+  pushAttrList(nullptr, nullptr);
 }
 
 void pushAttrList(char const* /*first*/, char const* /*last*/)
 {
-//   kDebug() << "Pushing attributes";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Pushing attributes";
   if (phelper)
   {
     phelper->graphAttributesStack.push_back(phelper->graphAttributes);
@@ -228,12 +230,12 @@ void pushAttrList(char const* /*first*/, char const* /*last*/)
 
 void popAttrListC(char const /*c*/)
 {
-  popAttrList(0,0);
+  popAttrList(nullptr, nullptr);
 }
 
 void popAttrList(char const* /*first*/, char const* /*last*/)
 {
-//   kDebug() << "Poping attributes";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Poping attributes";
   if (phelper) 
   {
     phelper->graphAttributes = phelper->graphAttributesStack.back();
@@ -243,13 +245,13 @@ void popAttrList(char const* /*first*/, char const* /*last*/)
     phelper->edgesAttributes = phelper->edgesAttributesStack.back();
     phelper->edgesAttributesStack.pop_back();
   }
-//   kDebug() << "Poped";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Poped";
 }
 
 void createnode(char const* first, char const* last)
 {
-//   kDebug() << (void*)first << (void*)last << QString::fromStdString(std::string(first,last));
-  if (phelper!=0 && first!=0 && last != 0) 
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << (void*)first << (void*)last << QString::fromStdString(std::string(first,last));
+  if (phelper && first && last)
   {
     std::string id(first,last);
     if (id.size()>0 && id[0] == '"') id = id.substr(1);
@@ -268,7 +270,7 @@ void createsubgraph(char const /*c*/)
 
 void setgraphattributes(char const* /*first*/, char const* /*last*/)
 {
-//   kDebug() << "setgraphattributes with z = " << phelper->z;
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "setgraphattributes with z = " << phelper->z;
   if (phelper) 
   {
     if (phelper->z == 1) // main graph
@@ -284,7 +286,7 @@ void setgraphattributes(char const* /*first*/, char const* /*last*/)
 
 void setnodeattributes(char const* /*first*/, char const* /*last*/)
 {
-//   kDebug() << "setnodeattributes with z = " << phelper->z;
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "setnodeattributes with z = " << phelper->z;
   if (phelper) 
   {
     phelper->setnodeattributes();
@@ -308,13 +310,13 @@ void checkedgeop(char const* first, char const* last)
       ( (!phelper->graph->directed()) && (str == "--") ) )
       return;
     
-    kError() << "Error !! uncoherent relation : directed = '" << phelper->graph->directed() << "' and op = '" << QString::fromStdString(str) << "'" << endl;
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "Error !! uncoherent relation : directed = '" << phelper->graph->directed() << "' and op = '" << QString::fromStdString(str) << "'" << endl;
   }
 }
 
 void edgebound(char const* first, char const* last)
 {
-//   kDebug() << "edgebound: " << QString::fromStdString(std::string(first,last));
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "edgebound: " << QString::fromStdString(std::string(first,last));
   if (phelper) 
   {
     std::string id(first,last);
@@ -357,7 +359,7 @@ bool parse_point(char const* str, QPoint& p)
 
 bool parse_numeric_color(char const* str, QColor& c)
 {
-  if (str==0) return false;
+  if (str == nullptr) return false;
   int r,g,b,a;
   bool res;
   uint_parser<unsigned, 16, 2, 2> hex2digits_p;
@@ -414,7 +416,7 @@ bool parse_integers(char const* str, std::vector<int>& v)
 
 bool parse_spline(char const* str, QVector< QPair< float, float > >& points)
 {
-//   kDebug() << "Parsing spline..." << QString::fromStdString(str);
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Parsing spline..." << QString::fromStdString(str);
   char e = 'n', s = 'n';
   int sx,sy,ex,ey;
   QPair< float, float > p;
@@ -435,7 +437,7 @@ bool parse_spline(char const* str, QVector< QPair< float, float > >& points)
   if (!res) return false;
   if (s == 's')
   {
-//     kDebug() << "inserting the s point";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "inserting the s point";
     points.insert(points.begin(), qMakePair(float(sx),float(sy)));
   }
   if (e == 'e')
@@ -447,7 +449,7 @@ bool parse_spline(char const* str, QVector< QPair< float, float > >& points)
 
 DotRenderOp renderop ;
 
-DotRenderOpVec* renderopvec = 0;
+DotRenderOpVec* renderopvec = nullptr;
 
 void init_op()
 {
@@ -460,7 +462,7 @@ void valid_op(char const* first, char const* last)
   renderop.renderop = QString::fromUtf8(therenderop.c_str());
   renderop.str = QString::fromUtf8(thestr.c_str());
 
-//   kDebug() << "Validating render operation '"<<QString::fromStdString(s)<<"': '"<<renderop.renderop<<"/"<<renderop.str<<"'";
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "Validating render operation '"<<QString::fromStdString(s)<<"': '"<<renderop.renderop<<"/"<<renderop.str<<"'";
   renderopvec->push_back(renderop);
   renderop.renderop = "";
   renderop.integers = QList<int>();
@@ -469,7 +471,7 @@ void valid_op(char const* first, char const* last)
 
 bool parse_renderop(const std::string& str, DotRenderOpVec& arenderopvec)
 {
-//   kDebug() << QString::fromUtf8(str.c_str()) << str.size();
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << QString::fromUtf8(str.c_str()) << str.size();
   if (str.empty())
   {
     return false;
@@ -526,8 +528,8 @@ bool parse_renderop(const std::string& str, DotRenderOpVec& arenderopvec)
              ).full;
   if (res ==false)
   {
-    kError() << "ERROR: parse_renderop failed on "<< QString::fromStdString(str);
-    kError() << "       Last renderop string is "<<QString::fromStdString(str.c_str());
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "ERROR: parse_renderop failed on "<< QString::fromStdString(str);
+    qCWarning(KGRAPHVIEWERLIB_LOG) << "       Last renderop string is "<<QString::fromStdString(str.c_str());
   }
 //   delete renderop; renderop = 0;
   return res;
